==> nextcloud-31.0.7-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/photos/l10n/zh_TW.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "公開連結",
    "Photos" : "照片",
    "On This Day" : "在這天",
    "Your memories under your control" : "完全自主掌控您珍貴的回憶",
    "All media" : "所有媒體",
    "Videos" : "影片",
    "Albums" : "相簿",
    "Collaborative albums" : "協作相簿",
    "People" : "人物",
    "Folders" : "資料夾",
    "Favorites" : "我的最愛",
    "On this day" : "在這天",
    "Shared with you" : "與您分享",
    "Tags" : "標籤",
    "Places" : "地點",
    "Map" : "地圖",
    "Photos settings" : "照片設定",
    "Mark selection as favorite" : "將選取範圍標記為最愛",
    "Add selection to favorites" : "新增選取範圍至最愛",
    "Remove selection from favorites" : "從最愛移除選取範圍",
    "Name of the album" : "相簿名稱",
    "Location of the album" : "相簿位置",
    "Back" : "返回",
    "Add collaborators" : "新增協作者",
    "Save" : "儲存",
    "Create album" : "建立相簿",
    "Add to Album" : "新增至相簿",
    "Add selection to album {albumName}" : "新增選取範圍至相簿 {albumName}",
    "Shared by" : "分享自",
    "Create a new album." : "建立新相簿。",
    "Create new album" : "建立新相簿",
    "New album" : "新相簿",
    "_%n item_::_%n photos and videos_" : ["%n 個照片與影片"],
    "Failed to fetch collaborators list." : "擷取協作者清單失敗。",
    "Failed to update album." : "更新相簿失敗。",
    "Add people or groups who can edit your album" : "新增可以編輯您的相簿的使用者或群組",
    "Search people or groups" : "搜尋使用者或群組",
    "No recommendations. Start typing." : "無建議。開始輸入。",
    "Group" : "群組",
    "Remove {collaboratorLabel} from the collaborators list" : "從協作者清單移除 {collaboratorLabel}",
    "Copy the public link" : "複製公開連結",
    "Public link copied!" : "已複製公開連結！",
    "Copy public link" : "複製公開連結",
    "Delete the public link" : "刪除公開連結",
    "Create public link share" : "建立公開連結分享",
    "Share via public link" : "透過公開連結分享",
    "This collection does not exist" : "此收藏不存在",
    "An error occurred" : "發生錯誤",
    "No picture for this day" : "這天沒有照片",
    "Picture taken on this day will show up here." : "這天拍攝的照片將會顯示在此處。",
    "More photos from this day" : "更多這天的照片",
    "_%n photos_::_%n photos_" : ["%n 個照片"],
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n 個未指派的照片"],
    "Favorite" : "收藏",
    "Favorite image, open the full size \"{name}\" image" : "收藏影像，開啟「{name}」的原始尺寸影像",
    "Open the full size \"{name}\" image" : "開啟「{name}」的原始尺寸影像",
    "Select image {imageName}" : "選取圖片 {imageName}",
    "Open the \"{name}\" folder" : "開啟「{name}」資料夾",
    "Go back" : "返回",
    "Date range" : "日期範圍",
    "Select a date range" : "選取日期範圍",
    "Select places" : "選取地點",
    "Dates" : "日曆",
    "Jump to specific date in list" : "跳到清單中的指定日期",
    "Jump to {date}" : "跳到 {date}",
    "Add to {destination}" : "新增至 {destination}",
    "The destination folder is owned by {owner}" : "目標資料夾為 {owner} 擁有",
    "There are no photos or videos yet!" : "還沒有照片或影片！",
    "_{years} year ago_::_{years} years ago_" : ["{years} 年前"],
    "Enable squared photos view" : "啟用方形照片檢視",
    "Delete source directory" : "刪除來源目錄",
    "Pick folder" : "挑選資料夾",
    "Select a source folder for your media" : "選取您媒體的來源資料夾",
    "All folders" : "所有資料夾",
    "Add a Photos source for the timelines" : "新增時間軸的照片來源",
    "Add folder" : "新增資料夾",
    "Select the default upload location for your media" : "選取您媒體的預設上傳位置",
    "Home" : "家庭",
    "Choose default Photos upload and Albums location" : "選擇預設照片上傳與相簿位置",
    "Choose a different folder" : "選擇其他資料夾",
    "View" : "檢視",
    "Media folders" : "媒體資料夾",
    "Choose the folders from where photos and videos are shown." : "選擇顯示照片與影片的資料夾。",
    "Upload folder" : "上傳資料夾",
    "Choose the folder where photos and albums are uploaded to." : "選擇照片與相簿上傳到的資料夾。",
    "_%n photo_::_%n photos_" : ["%n 張照片"],
    "Unselect all" : "取消全選",
    "Toggle filter" : "切換篩選器",
    "Add photos to this album" : "新增照片至此相簿",
    "Manage collaborators for this album" : "管理此相簿的協作者",
    "Open actions menu" : "開啟動作選單",
    "Edit album details" : "編輯相簿詳細資訊",
    "Download all files in album" : "下載相簿中的所有檔案",
    "Delete album" : "刪除相簿",
    "Download selected files" : "下載已選取的檔案",
    "Remove selection from album" : "從相簿移除選取範圍",
    "This album does not have any photos or videos yet!" : "此相簿還沒有任何照片或影片！",
    "Add photos to {albumName}" : "新增照片至 {albumName}",
    "Manage collaborators" : "管理協作者",
    "Save collaborators for this album." : "儲存此相簿的協作者。",
    "Cover photo for album {albumName}" : "相簿 {albumName} 的封面照片",
    "There is no album yet!" : "尚無相簿！",
    "This person could not be found" : "找不到此人",
    "Rename person" : "重新命名人",
    "Merge with different person" : "與其他人合併",
    "Download selected photos" : "下載選定的照片",
    "Remove from favorites" : "從最愛中移除",
    "Remove person" : "移除人",
    "Name of this person" : "此人的名字",
    "Save." : "儲存。",
    "Merge person" : "合併人",
    "Move to different person" : "移動至其他人",
    "_Move photo to a different person_::_Move photos to a different person_" : ["將照片移動為其他人"],
    "_Remove photo from person_::_Remove photos from person_" : ["從人移除照片"],
    "This might take some time depending on the size of your photo library." : "這可能需要花一點時間，取決於您照片庫的大小。",
    "Recognized people will show up here" : "被識別的人將會出現在此處",
    "This folder does not exist" : "此資料夾不存在",
    "Loading folders …" : "正在載入資料夾……",
    "No photos in here" : "此處無圖片檔案",
    "Taken on {date} at {time}" : "拍攝於 {date} 的 {time}",
    "This place does not have any photos or videos yet!" : "此處還沒有任何照片或影片！",
    "Add photos to this place" : "新增照片至此處",
    "Cover photo for place {placeName}" : "地點 {placeName} 的封面照片",
    "There is no place yet!" : "還沒有地點！",
    "Cover photo for shared album {albumName}" : "共享相簿 {albumName} 的封面照片",
    "Back to tags overview" : "回到標籤概覽",
    "No photos with this tag yet" : "還沒有帶有此標籤的照片",
    "No tags yet" : "尚未加入標籤",
    "Photos with tags will show up here" : "此處會顯示圖片的標籤",
    "Popular tags" : "熱門標籤",
    "All tags" : "全部標籤",
    "Create new album from filters" : "從篩選條件建立新相簿",
    "One of the source folders does not exist" : "其中一個來源資料夾不存在",
    "Add to album" : "新增至相簿",
    "Delete selection" : "刪除選擇",
    "No photos or videos in here" : "此處沒有照片或影片",
    "Unassigned faces" : "未指派的臉孔",
    "Failed to fetch collection." : "擷取收藏品失敗。",
    "Failed to fetch collections list." : "擷取收藏清單失敗。",
    "Failed to fetch faces list." : "擷取臉部清單失敗。",
    "Error fetching files" : "擷取檔案時發生錯誤",
    "All your media" : "您所有的媒體",
    "Album {title}" : "相簿 {title}",
    "Shared Albums" : "已分享的相簿",
    "Shared album {title}" : "已分享的相簿 {title}",
    "Public album {title}" : "公開相簿 {title}",
    "Tagged photos" : "有標籤的照片",
    "Tagged photo {title}" : "已標記的照片 {title}",
    "{title}'s face" : "{title} 的臉",
    "{startDate} to {endDate}" : "{startDate} 到 {endDate}",
    "Details" : "詳細資訊",
    "Failed to add {fileBaseName} to collection {collectionFileName}" : "無法將 {fileBaseName} 新增至收藏 {collectionFileName}",
    "Failed to delete {fileBaseName}" : "刪除 {fileBaseName} 失敗",
    "Failed to create {collectionFileName}" : "建立 {collectionFileName} 失敗",
    "Failed to rename {currentCollectionFileName} to {newCollectionFileName}" : "無法將 {currentCollectionFileName} 重新命名為 {newCollectionFileName}",
    "Failed to update properties of {collectionFileName} with {properties}" : "無法使用 {properties} 更新 {collectionFileName} 的屬性",
    "Failed to delete {collectionFileName}" : "刪除 {collectionFileName} 失敗",
    "Failed to move {fileBaseName} to person {faceName}" : "將 {fileBaseName} 移動到人物 {faceName} 失敗",
    "Failed to remove {fileBaseName}" : "移除 {fileBaseName} 失敗",
    "Failed to rename {oldName} to {faceName}" : "無法將 {oldName} 重新命名為 {faceName}",
    "Failed to delete {faceName}" : "刪除 {faceName} 失敗",
    "Failed to delete {fileId}" : "刪除 {fileId} 失敗",
    "Failed to delete {fileName}" : "刪除 {fileName} 失敗",
    "Failed to set favorite state for {fileId}" : "無法設定 {fileId} 的收藏狀態",
    "Failed to set favorite state for {fileName}" : "無法設定 {fileName} 的收藏狀態",
    "Could not load photos folder" : "無法載入照片資料夾",
    "Back to {folder}" : "回到 {folder}",
    "Share this folder" : "分享此資料夾",
    "One of the source folders does not exists" : "其中一個來源資料夾不存在",
    "Add" : "新增"
},
"nplurals=1; plural=0;");

==> nextcloud-31.0.9-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/photos/l10n/zh_TW.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "公開連結",
    "Photos" : "照片",
    "On This Day" : "在這天",
    "Your memories under your control" : "完全自主掌控您珍貴的回憶",
    "All media" : "所有媒體",
    "Videos" : "影片",
    "Albums" : "相簿",
    "Collaborative albums" : "協作相簿",
    "People" : "人物",
    "Folders" : "資料夾",
    "Favorites" : "我的最愛",
    "On this day" : "在這天",
    "Shared with you" : "與您分享",
    "Tags" : "標籤",
    "Places" : "地點",
    "Map" : "地圖",
    "Photos settings" : "照片設定",
    "Mark selection as favorite" : "將選取範圍標記為最愛",
    "Add selection to favorites" : "新增選取範圍至最愛",
    "Remove selection from favorites" : "從最愛移除選取範圍",
    "Name of the album" : "相簿名稱",
    "Location of the album" : "相簿位置",
    "Back" : "返回",
    "Add collaborators" : "新增協作者",
    "Save" : "儲存",
    "Create album" : "建立相簿",
    "Add to Album" : "新增至相簿",
    "Add selection to album {albumName}" : "新增選取範圍至相簿 {albumName}",
    "Shared by" : "分享自",
    "Create a new album." : "建立新相簿。",
    "Create new album" : "建立新相簿",
    "New album" : "新相簿",
    "_%n item_::_%n photos and videos_" : ["%n 個照片與影片"],
    "Failed to fetch collaborators list." : "擷取協作者清單失敗。",
    "Failed to update album." : "更新相簿失敗。",
    "Add people or groups who can edit your album" : "新增可以編輯您的相簿的使用者或群組",
    "Search people or groups" : "搜尋使用者或群組",
    "No recommendations. Start typing." : "無建議。開始輸入。",
    "Copy the public link" : "複製公開連結",
    "Public link copied!" : "已複製公開連結！",
    "Copy public link" : "複製公開連結",
    "Delete the public link" : "刪除公開連結",
    "Create public link share" : "建立公開連結分享",
    "Share via public link" : "透過公開連結分享",
    "This collection does not exist" : "此收藏不存在",
    "An error occurred" : "發生錯誤",
    "No picture for this day" : "這天沒有照片",
    "Picture taken on this day will show up here." : "這天拍攝的照片將會顯示在此處。",
    "More photos from this day" : "更多這天的照片",
    "_%n photos_::_%n photos_" : ["%n 個照片"],
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n 個未指派的照片"],
    "Favorite" : "收藏",
    "Favorite image, open the full size \"{name}\" image" : "收藏影像，開啟「{name}」的原始尺寸影像",
    "Open the full size \"{name}\" image" : "開啟「{name}」的原始尺寸影像",
    "Select image {imageName}" : "選取圖片 {imageName}",
    "Open the \"{name}\" folder" : "開啟「{name}」資料夾",
    "Go back" : "返回",
    "Select a custom date range" : "選取自訂日期範圍",
    "Select a date range" : "選取日期範圍",
    "Date range" : "日期範圍",
    "Select filters" : "選取篩選條件",
    "Dates" : "日曆",
    "Jump to specific date in list" : "跳到清單中的指定日期",
    "Jump to {date}" : "跳到 {date}",
    "Add to {destination}" : "新增至 {destination}",
    "The destination folder is owned by {owner}" : "目標資料夾為 {owner} 擁有",
    "There are no photos or videos yet!" : "還沒有照片或影片！",
    "_{years} year ago_::_{years} years ago_" : ["{years} 年前"],
    "Enable squared photos view" : "啟用方形照片檢視",
    "Delete source directory" : "刪除來源目錄",
    "Pick folder" : "挑選資料夾",
    "Select a source folder for your media" : "選取您媒體的來源資料夾",
    "All folders" : "所有資料夾",
    "Add a Photos source for the timelines" : "新增時間軸的照片來源",
    "Add folder" : "新增資料夾",
    "Select the default upload location for your media" : "選取您媒體的預設上傳位置",
    "Home" : "家庭",
    "Choose default Photos upload and Albums location" : "選擇預設照片上傳與相簿位置",
    "Choose a different folder" : "選擇其他資料夾",
    "View" : "檢視",
    "Media folders" : "媒體資料夾",
    "Choose the folders from where photos and videos are shown." : "選擇顯示照片與影片的資料夾。",
    "Upload folder" : "上傳資料夾",
    "Choose the folder where photos and albums are uploaded to." : "選擇照片與相簿上傳到的資料夾。",
    "_%n photo_::_%n photos_" : ["%n 張照片"],
    "Unselect all" : "取消全選",
    "Add photos to this album" : "新增照片至此相簿",
    "Manage collaborators for this album" : "管理此相簿的協作者",
    "Open actions menu" : "開啟動作選單",
    "Edit album details" : "編輯相簿詳細資訊",
    "Download all files in album" : "下載相簿中的所有檔案",
    "Delete album" : "刪除相簿",
    "Download selected files" : "下載已選取的檔案",
    "Remove selection from album" : "從相簿移除選取範圍",
    "This album does not have any photos or videos yet!" : "此相簿還沒有任何照片或影片！",
    "Add photos to {albumName}" : "新增照片至 {albumName}",
    "Manage collaborators" : "管理協作者",
    "Save collaborators for this album." : "儲存此相簿的協作者。",
    "Cover photo for album {albumName}" : "相簿 {albumName} 的封面照片",
    "There is no album yet!" : "尚無相簿！",
    "This person could not be found" : "找不到此人",
    "Rename person" : "重新命名人",
    "Merge with different person" : "與其他人合併",
    "Download selected photos" : "下載選定的照片",
    "Remove from favorites" : "從最愛中移除",
    "Remove person" : "移除人",
    "Name of this person" : "此人的名字",
    "Save." : "儲存。",
    "Merge person" : "合併人",
    "Move to different person" : "移動至其他人",
    "_Move photo to a different person_::_Move photos to a different person_" : ["將照片移動為其他人"],
    "_Remove photo from person_::_Remove photos from person_" : ["從人移除照片"],
    "This might take some time depending on the size of your photo library." : "這可能需要花一點時間，取決於您照片庫的大小。",
    "Recognized people will show up here" : "被識別的人將會出現在此處",
    "This folder does not exist" : "此資料夾不存在",
    "Loading folders…" : "載入資料夾…",
    "No photos in here" : "此處無圖片檔案",
    "Taken on {date} at {time}" : "拍攝於 {date} 的 {time}",
    "This place does not have any photos or videos yet!" : "此處還沒有任何照片或影片！",
    "Add photos to this place" : "新增照片至此處",
    "Cover photo for place {placeName}" : "地點 {placeName} 的封面照片",
    "There is no place yet!" : "還沒有地點！",
    "Cover photo for shared album {albumName}" : "共享相簿 {albumName} 的封面照片",
    "Back to tags overview" : "回到標籤概覽",
    "No photos with this tag yet" : "還沒有帶有此標籤的照片",
    "No tags yet" : "尚未加入標籤",
    "Photos with tags will show up here" : "此處會顯示圖片的標籤",
    "Popular tags" : "熱門標籤",
    "All tags" : "全部標籤",
    "Create new album from filters" : "從篩選條件建立新相簿",
    "One of the source folders does not exist" : "其中一個來源資料夾不存在",
    "Add to album" : "新增至相簿",
    "Delete selection" : "刪除選擇",
    "No photos or videos in here" : "此處沒有照片或影片",
    "Unassigned faces" : "未指派的臉孔",
    "Failed to fetch collection." : "擷取收藏品失敗。",
    "Failed to fetch collections list." : "擷取收藏清單失敗。",
    "Failed to fetch faces list." : "擷取臉部清單失敗。",
    "Error fetching files" : "擷取檔案時發生錯誤",
    "All your media" : "您所有的媒體",
    "Album {title}" : "相簿 {title}",
    "Shared Albums" : "已分享的相簿",
    "Shared album {title}" : "已分享的相簿 {title}",
    "Public album {title}" : "公開相簿 {title}",
    "Tagged photos" : "有標籤的照片",
    "Tagged photo {title}" : "已標記的照片 {title}",
    "{title}'s face" : "{title} 的臉",
    "Last week" : "上星期",
    "Last Month" : "上個月",
    "Custom…" : "自訂……",
    "{startDate} to {endDate}" : "{startDate} 到 {endDate}",
    "Details" : "詳細資訊",
    "Failed to add {fileBaseName} to collection {collectionFileName}" : "無法將 {fileBaseName} 新增至收藏 {collectionFileName}",
    "Failed to delete {fileBaseName}" : "刪除 {fileBaseName} 失敗",
    "Failed to create {collectionFileName}" : "建立 {collectionFileName} 失敗",
    "Failed to rename {currentCollectionFileName} to {newCollectionFileName}" : "無法將 {currentCollectionFileName} 重新命名為 {newCollectionFileName}",
    "Failed to update properties of {collectionFileName} with {properties}" : "無法使用 {properties} 更新 {collectionFileName} 的屬性",
    "Failed to delete {collectionFileName}" : "刪除 {collectionFileName} 失敗",
    "Failed to move {fileBaseName} to person {faceName}" : "將 {fileBaseName} 移動到人物 {faceName} 失敗",
    "Failed to remove {fileBaseName}" : "移除 {fileBaseName} 失敗",
    "Failed to rename {oldName} to {faceName}" : "無法將 {oldName} 重新命名為 {faceName}",
    "Failed to delete {faceName}" : "刪除 {faceName} 失敗",
    "Failed to delete {fileId}" : "刪除 {fileId} 失敗",
    "Failed to delete {fileName}" : "刪除 {fileName} 失敗",
    "Failed to set favorite state for {fileId}" : "無法設定 {fileId} 的收藏狀態",
    "Failed to set favorite state for {fileName}" : "無法設定 {fileName} 的收藏狀態",
    "Could not load photos folder" : "無法載入照片資料夾",
    "Group" : "群組",
    "Remove {collaboratorLabel} from the collaborators list" : "從協作者清單移除 {collaboratorLabel}",
    "Back to {folder}" : "回到 {folder}",
    "Share this folder" : "分享此資料夾",
    "Loading folders …" : "正在載入資料夾……",
    "One of the source folders does not exists" : "其中一個來源資料夾不存在",
    "Add" : "新增"
},
"nplurals=1; plural=0;");
